@@ -1,5 +1,5 @@
 `JGET.seis` <-
-function(fnames, kind=1, Iendian=1, BIGLONG=FALSE , HEADONLY=FALSE , PLOT=FALSE)
+function(fnames, kind=1, Iendian=1, BIGLONG=FALSE, HEADONLY=FALSE , PLOT=FALSE)
 {
   ###  get a bunch of AH files from a directory and store in structure
   ####  kind 1=segy, 2=sac, 3=AH, kind=0->R format
@@ -8,7 +8,7 @@ function(fnames, kind=1, Iendian=1, BIGLONG=FALSE , HEADONLY=FALSE , PLOT=FALSE)
   if(missing(kind)) { kind=1 }
   if(missing(HEADONLY)) {HEADONLY=FALSE }
   if(missing(Iendian)) { Iendian=1 }
-     if(missing(BIGLONG)) { BIGLONG=TRUE}
+     if(missing(BIGLONG)) { BIGLONG=FALSE}
 
   
   GIVE = as.list(1:length(fnames))
